@@ -2,7 +2,9 @@
 # This is so ruff doesn't remove * imports
 
 from .simple import *
+from .redis import *
 
 __all__ = [
     "SimpleCache",
+    "RedisCache",
 ]
